Index: FL/Fl_Help_View.H
===================================================================
--- FL/Fl_Help_View.H	(Revision 12212)
+++ FL/Fl_Help_View.H	(Arbeitskopie)
@@ -264,12 +264,12 @@
   void		draw();
 private:
   void		format();
-  void		format_table(int *table_width, int *columns, const char *table);
+  const char *format_table(int *table_width, int *columns, const char *table);
   void		free_data();
   int		get_align(const char *p, int a);
   const char	*get_attr(const char *p, const char *n, char *buf, int bufsize);
   Fl_Color	get_color(const char *n, Fl_Color c);
-  Fl_Shared_Image *get_image(const char *name, int W, int H);
+  Fl_Shared_Image *get_image(const char *name, int W, int H, bool refetch=false);
   int		get_length(const char *l);
 public:
   int		handle(int);
Index: src/Fl_Help_View.cxx
===================================================================
--- src/Fl_Help_View.cxx	(Revision 12212)
+++ src/Fl_Help_View.cxx	(Arbeitskopie)
@@ -1258,6 +1258,7 @@
 				// Cells in the current row...
 		row;		// Current table row (block number)
   const char	*ptr,		// Pointer into block
+		*lptr,		// Last turn's Pointer into block
 		*start,		// Pointer to start of element
 		*attrs;		// Pointer to start of element attributes
   HV_Edit_Buffer buf;		// Text buffer
@@ -1294,6 +1295,7 @@
   hsize_ = w() - scrollsize - Fl::box_dw(b);
 
   done = 0;
+  lptr = value_;
   while (!done)
   {
     // Reset state variables...
@@ -1349,6 +1351,7 @@
           if (ww > hsize_) {
 	    hsize_ = ww;
 	    done   = 0;
+       lptr = ptr;
 	    break;
 	  }
 
@@ -1411,6 +1414,7 @@
           if (xx > hsize_) {
 	    hsize_ = xx;
 	    done   = 0;
+       lptr = ptr;
 	    break;
 	  }
 
@@ -1539,7 +1543,7 @@
 
 	    block->h += fsize + 2;
 
-            format_table(&table_width, columns, start);
+            lptr = format_table(&table_width, columns, start);
 
             if ((xx + table_width) > hsize_) {
 #ifdef DEBUG
@@ -1548,6 +1552,7 @@
 #endif // DEBUG
 	      hsize_ = xx + table_width;
 	      done   = 0;
+         lptr = ptr;
 	      break;
 	    }
 
@@ -1875,7 +1880,7 @@
 	  height = get_length(hattr);
 
 	  if (get_attr(attrs, "SRC", attr, sizeof(attr))) {
-	    img    = get_image(attr, width, height);
+	    img    = get_image(attr, width, height, ptr <= lptr);
 	    width  = img->w();
 	    height = img->h();
 	  }
@@ -1885,6 +1890,7 @@
           if (ww > hsize_) {
 	    hsize_ = ww;
 	    done   = 0;
+       lptr = ptr;
 	    break;
 	  }
 
@@ -1919,6 +1925,7 @@
         if (xx > hsize_) {
 	  hsize_ = xx;
           done   = 0;
+     lptr = ptr;
 	  break;
 	}
 
@@ -1973,6 +1980,7 @@
       if (ww > hsize_) {
 	hsize_ = ww;
 	done   = 0;
+   lptr = ptr;
 	break;
       }
 
@@ -2056,7 +2064,7 @@
 
 
 /** Formats a table */
-void
+const char *
 Fl_Help_View::format_table(int        *table_width,	// O - Total table width
                            int        *columns,		// O - Column widths
 	                   const char *table)		// I - Pointer to start of table
@@ -2398,7 +2406,7 @@
 #endif // DEBUG
 
   if (num_columns == 0)
-    return;
+    return ptr;
 
   // Add up the widths...
   for (column = 0, width = 0; column < num_columns; column ++)
@@ -2474,6 +2482,8 @@
   for (column = 0; column < num_columns; column ++)
     printf("    columns[%d] = %d\n", column, columns[column]);
 #endif // DEBUG
+
+  return ptr;
 }
 
 
@@ -2770,7 +2780,7 @@
 */
 
 Fl_Shared_Image *
-Fl_Help_View::get_image(const char *name, int W, int H) {
+Fl_Help_View::get_image(const char *name, int W, int H, bool refetch/*=false*/) {
   const char	*localname;		// Local filename
   char		dir[FL_PATH_MAX];	// Current directory
   char		temp[FL_PATH_MAX],	// Temporary filename
@@ -2809,7 +2819,7 @@
 
   if (strncmp(localname, "file:", 5) == 0) localname += 5;
 
-  if (initial_load) {
+  if (initial_load && !refetch) {
     if ((ip = Fl_Shared_Image::get(localname, W, H)) == NULL) {
       ip = (Fl_Shared_Image *)&broken_image;
     }
